@@ -4,13 +4,13 @@
 (defparameter *autoconf-prefix* "/usr/local")
 (defparameter *autoconf-exec_prefix* "/usr/local")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.46.0")
+(defparameter *autoconf-version* "5.48.0")
 (defparameter *autoconf-libdir* "/usr/local/lib")
 (defparameter *autoconf-libexecdir* "/usr/local/libexec")
 (defparameter *autoconf-datadir* "/usr/local/share")
 (defparameter *autoconf-infodir* "/usr/local/info")
-(defparameter *autoconf-host* "i386-unknown-openbsd7.6")
-;; This variable is kept for backwards compatibiliy reasons:
+(defparameter *autoconf-host* "x86_64-unknown-openbsd7.7")
+;; This variable is kept for backwards compatibility reasons:
 ;; We seem to be in the fortunate position that we sometimes need to check for windows.
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
@@ -20,5 +20,5 @@
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/pobj/maxima-5.46.0/maxima-5.46.0")
+(defparameter *maxima-source-root* "/usr/obj/ports/maxima-5.48.0/maxima-5.48.0")
 (defparameter *maxima-default-layout-autotools* "true")
